{ config, pkgs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../../modules
    ../../users/simon
  ];

  sbruder = {
    cpu.intel.enable = true;
    gpu.amd.enable = true;
    gui.enable = true;
    libvirt.enable = true;
    restic.enable = true;
    ssd.enable = true;
    wireguard.home = {
      enable = true;
      address = "10.80.0.5";
    };
  };

  boot.loader.grub.device = "/dev/disk/by-id/ata-MTFDDAK256TBN-1AR15ABHA_UFZMQ01ZR50NMM";

  boot.initrd.luks.devices = {
    root = {
      name = "root";
      device = "/dev/disk/by-uuid/d7e4d213-8a13-4059-a011-0f68081e86d8";
      preLVM = true;
      allowDiscards = true;
    };
  };

  fileSystems.data = {
    mountPoint = "/data";
    device = "/dev/mapper/data";
    encrypted = {
      label = "data";
      enable = true;
      blkDev = "/dev/disk/by-uuid/576088d4-9aae-4159-a028-feadb2621a1a";
      keyFile = "/mnt-root" + toString ./secrets/data_luks_key;
    };
  };

  networking.hostName = "sayuri";
}
